summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirstatapp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdirstat/kdirstatapp.h')
-rw-r--r--kdirstat/kdirstatapp.h58
1 files changed, 29 insertions, 29 deletions
diff --git a/kdirstat/kdirstatapp.h b/kdirstat/kdirstatapp.h
index d23e5f9..e2a0108 100644
--- a/kdirstat/kdirstatapp.h
+++ b/kdirstat/kdirstatapp.h
@@ -27,15 +27,15 @@
class TQPopupMenu;
class TQSplitter;
-class KAction;
+class TDEAction;
class KActivityTracker;
class KFeedbackDialog;
class KFeedbackDialog;
class KFeedbackQuestion;
class KPacMan;
class KPacMan;
-class KRecentFilesAction;
-class KToggleAction;
+class TDERecentFilesAction;
+class TDEToggleAction;
namespace KDirStat
{
@@ -56,10 +56,10 @@ using namespace KDirStat;
* and reads the config file as well as providing a menubar, toolbar and
* statusbar. An instance of KDirStatView creates your center view, which is
* connected to the window's Doc object. KDirStatApp reimplements the methods
* that KMainWindow provides for main window handling and supports full
* session management as well as using KActions.
*
- * @see KMainWindow
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig
*
@@ -68,7 +68,7 @@ using namespace KDirStat;
*
* @version KDevelop version 1.2 code generation
**/
-class KDirStatApp : public KMainWindow
+class KDirStatApp : public TDEMainWindow
{
Q_OBJECT
@@ -304,7 +304,7 @@ signals:
protected:
/**
- * Initialize the KActions of the application.
+ * Initialize the TDEActions of the application.
**/
void initActions();
@@ -388,27 +388,27 @@ protected:
// Actions
- KAction * _fileAskOpenDir;
- KAction * _fileAskOpenUrl;
- KRecentFilesAction * _fileOpenRecent;
- KAction * _fileCloseDir;
- KAction * _fileRefreshAll;
- KAction * _fileRefreshSelected;
- KAction * _fileContinueReadingAtMountPoint;
- KAction * _fileStopReading;
- KAction * _fileQuit;
- KAction * _editCopy;
- KAction * _cleanupOpenWith;
- KAction * _treemapZoomIn;
- KAction * _treemapZoomOut;
- KAction * _treemapSelectParent;
- KAction * _treemapRebuild;
-
- KAction * _reportMailToOwner;
- KAction * _helpSendFeedbackMail;
- KToggleAction * _showToolBar;
- KToggleAction * _showStatusBar;
- KToggleAction * _showTreemapView;
+ TDEAction * _fileAskOpenDir;
+ TDEAction * _fileAskOpenUrl;
+ TDERecentFilesAction * _fileOpenRecent;
+ TDEAction * _fileCloseDir;
+ TDEAction * _fileRefreshAll;
+ TDEAction * _fileRefreshSelected;
+ TDEAction * _fileContinueReadingAtMountPoint;
+ TDEAction * _fileStopReading;
+ TDEAction * _fileQuit;
+ TDEAction * _editCopy;
+ TDEAction * _cleanupOpenWith;
+ TDEAction * _treemapZoomIn;
+ TDEAction * _treemapZoomOut;
+ TDEAction * _treemapSelectParent;
+ TDEAction * _treemapRebuild;
+
+ TDEAction * _reportMailToOwner;
+ TDEAction * _helpSendFeedbackMail;
+ TDEToggleAction * _showToolBar;
+ TDEToggleAction * _showStatusBar;
+ TDEToggleAction * _showTreemapView;
KCleanupCollection * _cleanupCollection;
@@ -56,10 +56,10 @@ using namespace KDirStat;
* statusbar. An instance of KDirStatView creates your center view, which is
* connected to the window's Doc object. KDirStatApp reimplements the methods
- * that KMainWindow provides for main window handling and supports full
- * session management as well as using KActions.
+ * that TDEMainWindow provides for main window handling and supports full
+ * session management as well as using TDEActions.
*